@@ -17,7 +17,7 @@ def NSMOsetValue_ForKey_(self, name, value):
         else:
             self.setValue_forKey_(value, name)
 
-    except KeyError, msg:
+    except KeyError as msg:
         NSObject.__setattr__(self, name, value)
 
 
@@ -28,7 +28,7 @@ def NSMOgetValueForKey_(self, name):
         else:
             return self.valueForKey_(name)
         
-    except KeyError, msg:
+    except KeyError as msg:
         raise AttributeError(name)
 
 addConvenienceForClass('NSManagedObject', (
