@@ -14,6 +14,11 @@ class TestNSMigrationManager (TestCase):
         #self.assertArgIsOut(NSMigrationManager.loadMetadata_, 0)
         #self.assertResultIsBOOL(NSMigrationManager.loadMetadata_)
         pass
+    
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertArgIsBOOL(NSMigrationManager.setUsesStoreSpecificMigrationManager_, 0)
+        self.assertResultIsBOOL(NSMigrationManager.usesStoreSpecificMigrationManager)
 
 if __name__ == "__main__":
     main()
